@@ -1,4 +1,4 @@
-import nexmo
+import vonage
 
 from ..Notifier import Notifier
 from ..utils import render
@@ -9,13 +9,14 @@ class VonageNotifier(Notifier):
         """
         .. seealso:: Notifier.send()
         """
-        client = nexmo.Client(
+        sms = vonage.Sms(
             key=self._config.get("vonage_key"), secret=self._config.get("vonage_secret")
         )
-        client.send_message(
+        sms.send_message(
             {
                 "from": render(self._config.get("from", "BackupUtils")),
                 "to": self._config.get("to"),
                 "text": msg,
+                "type": "unicode",
             }
         )
